==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/imaging/components/dicomdirectory/DicomDirectoryComponent.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef DICOMCOMPONENT_H
#define DICOMCOMPONENT_H

#include <QObject>

#include <ImageComponent.h>

class DicomDirectoryComponent : public camitk::ImageComponent {

    Q_OBJECT

public:
    /**
     * Create a new Component that handles DICOM image (from a directory)
     * @param path: the path to a directory containing several DICOM image files.
     **/
    DicomDirectoryComponent(const QString & path) throw(camitk::AbortException);

    /// Default Destructor
    virtual ~DicomDirectoryComponent();

};

#endif // DICOMCOMPONENT_H

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/imaging/components/dicomdirectory/DicomDirectoryComponent.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef DICOMCOMPONENT_H
#define DICOMCOMPONENT_H

#include <QObject>

#include <ImageComponent.h>

/** 
 * @ingroup group_cepimaging_components_dicomdirectory
 * 
 * @brief
 * DICOM directories Component which store DICOM images.
 * 
 * @note This @ref camitk::Component "Component" requires the GDCM library in order to work correctly.
 */
class DicomDirectoryComponent : public camitk::ImageComponent {

    Q_OBJECT

public:
    /**
     * Create a new Component that handles DICOM image (from a directory)
     * @param path: the path to a directory containing several DICOM image files.
     **/
    DicomDirectoryComponent(const QString & path) throw(camitk::AbortException);

    /// Default Destructor
    virtual ~DicomDirectoryComponent();

};

#endif // DICOMCOMPONENT_H
